..
      Copyright (C) 2015 Midokura SARL.
      All Rights Reserved.

      Licensed under the Apache License, Version 2.0 (the "License"); you may
      not use this file except in compliance with the License. You may obtain
      a copy of the License at

          http://www.apache.org/licenses/LICENSE-2.0

      Unless required by applicable law or agreed to in writing, software
      distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
      WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
      License for the specific language governing permissions and limitations
      under the License.

      Convention for heading levels in Networking MidoNet devref:
      =======  Heading 0 (reserved for the title in a document)
      -------  Heading 1
      ~~~~~~~  Heading 2
      +++++++  Heading 3
      '''''''  Heading 4
      (Avoid deeper levels because they do not render well.)


Developer Guide
===============

In the Developer Guide, you will find information on Networking MidoNet's lower
level designs.
The developer guide also includes information about testing infrastructure.


Programming HowTos and Tutorials
--------------------------------
.. toctree::
   :maxdepth: 3

   alembic_migrations
   testing
   packages


Networking MidoNet Internals
----------------------------
.. toctree::
   :maxdepth: 3

   firewall


Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
